==> aptechka-0.43.1.tgz: package/lib/controls/index.js <==
var V = (h) => {
  throw TypeError(h);
};
var S = (h, n, e) => n.has(h) || V("Cannot " + e);
var t = (h, n, e) => (S(h, n, "read from private field"), e ? e.call(h) : n.get(h)), s = (h, n, e) => n.has(h) ? V("Cannot add the same private member more than once") : n instanceof WeakSet ? n.add(h) : n.set(h, e), i = (h, n, e, a) => (S(h, n, "write to private field"), a ? a.call(h, e) : n.set(h, e), e), T = (h, n, e) => (S(h, n, "access private method"), e);
import { Notifier as G } from "../notifier/index.js";
import { i as o } from "../browser-0zX67oeU.js";
import { g as Q } from "../dom-CVWzyXPH.js";
import { ticker as k } from "../ticker/index.js";
import "../Store-Cm3LPXlx.js";
import { b as J } from "../easings-Bni3YAAW.js";
import { T as Z } from "../Tweened-p5hYr6lL.js";
import { s as $ } from "../gestures-D2Fdra_G.js";
import { p } from "../polyfills-CxfUK5OU.js";
import { TICK_ORDER as _ } from "../order/index.js";
var O;
class B {
  constructor() {
    s(this, O, new G());
  }
  get changeEvent() {
    return t(this, O);
  }
}
O = new WeakMap();
var g, d, m, P;
class me extends B {
  constructor(e) {
    super();
    s(this, g, null);
    s(this, d, null);
    s(this, m, "offsetHeight");
    s(this, P, (e) => {
      const a = e.shiftKey ? -1 : 1;
      let r;
      e.code === "Space" ? r = a * t(this, d)[t(this, m)] * 0.4 : e.code === "ArrowLeft" ? r = -1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowRight" ? r = 1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowUp" ? r = -1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowDown" ? r = 1 * t(this, d)[t(this, m)] * 0.2 : e.code === "PageUp" ? r = -1 * t(this, d)[t(this, m)] : e.code === "PageDown" ? r = 1 * t(this, d)[t(this, m)] : e.code === "Home" ? r = 0 : e.code === "End" && (r = t(this, m) === "offsetWidth" ? t(this, d).scrollWidth : t(this, d).scrollHeight), r && (e.stopPropagation(), this.changeEvent.notify("keyboard", r));
    });
    o && (i(this, g, e != null && e.element && Q(e.element) || window), i(this, d, t(this, g) instanceof HTMLElement ? t(this, g) : document.documentElement), this.dimension = e == null ? void 0 : e.dimension);
  }
  set dimension(e) {
    i(this, m, e === "width" ? "offsetWidth" : "offsetHeight");
  }
  connect() {
    o && t(this, g).addEventListener(
      "keydown",
      t(this, P)
    );
  }
  disconnect() {
    o && t(this, g).removeEventListener(
      "keydown",
      t(this, P)
    );
  }
}
g = new WeakMap(), d = new WeakMap(), m = new WeakMap(), P = new WeakMap();
var w, v, X, Y, c, C, f, b, K, U, A, q, I;
class fe extends B {
  constructor(e) {
    super();
    s(this, b);
    s(this, w);
    s(this, v);
    s(this, X);
    s(this, Y);
    s(this, c);
    s(this, C);
    s(this, f);
    s(this, A);
    s(this, q);
    s(this, I);
    this.direction = 1, i(this, c, new Z(0, { easing: J })), i(this, f, !1), i(this, A, (a) => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        a.timeBetweenFrames * t(this, w) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, q, () => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        Math.sign(t(this, w)) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, I, () => {
      t(this, v) && (document.hidden ? t(this, c).set(1, { equalize: !0 }) : t(this, c).set(0, { equalize: !0 }));
    }), i(this, w, (e == null ? void 0 : e.speed) || 1), i(this, v, (e == null ? void 0 : e.interval) || !1), i(this, X, e);
  }
  set interval(e) {
    i(this, v, e), t(this, f) && T(this, b, K).call(this);
  }
  set speed(e) {
    i(this, w, e), t(this, f) && T(this, b, K).call(this);
  }
  connect() {
    t(this, f) || (i(this, f, !0), T(this, b, K).call(this));
  }
  disconnect() {
    t(this, f) && (i(this, f, !1), T(this, b, U).call(this));
  }
  pauseAndContinue(e, a) {
    t(this, f) && e && (clearTimeout(t(this, C)), t(this, c).set(1, {
      duration: Math.min(e, 1e3),
      equalize: a
    }), i(this, C, setTimeout(() => {
      t(this, c).set(0, {
        duration: Math.min(e, 5e3),
        equalize: a
      });
    }, e)));
  }
}
w = new WeakMap(), v = new WeakMap(), X = new WeakMap(), Y = new WeakMap(), c = new WeakMap(), C = new WeakMap(), f = new WeakMap(), b = new WeakSet(), K = function() {
  T(this, b, U).call(this), t(this, v) ? i(this, Y, setInterval(
    t(this, q),
    Math.abs(t(this, w))
  )) : k.subscribe(t(this, A), t(this, X)), document.addEventListener(
    "visibilitychange",
    t(this, I)
  );
}, U = function() {
  clearInterval(t(this, Y)), k.unsubscribe(t(this, A)), clearTimeout(t(this, C)), t(this, c).close(), document.removeEventListener(
    "visibilitychange",
    t(this, I)
  );
}, A = new WeakMap(), q = new WeakMap(), I = new WeakMap();
var D, x, H, N;
class ue extends B {
  constructor(e) {
    super();
    s(this, D, null);
    s(this, x);
    s(this, H);
    s(this, N, (e) => {
      let a = 0;
      if (!(this.axis === "x" && Math.abs(e.deltaY) > Math.abs(e.deltaX) * 1 || this.axis === "y" && Math.abs(e.deltaX) > Math.abs(e.deltaY) * 1))
        if (e.preventDefault(), a = (this.axis === "max" ? Math.abs(e.deltaX) > Math.abs(e.deltaY) ? e.deltaX : e.deltaY : this.axis === "x" ? e.deltaX : e.deltaY) * this.speed, e.stopPropagation(), this.debounce) {
          const r = Date.now();
          if (r - t(this, H) > 40 && (a = 100 * Math.sign(a)), i(this, H, r), Math.abs(a) < 100 || t(this, x))
            return;
          this.changeEvent.notify("wheel", a), i(this, x, setTimeout(() => {
            i(this, x, void 0);
          }, 80));
        } else
          this.changeEvent.notify("wheel", a);
    });
    this.axis = (e == null ? void 0 : e.axis) || "y", this.speed = (e == null ? void 0 : e.speed) || 1, this.debounce = (e == null ? void 0 : e.debounce) || !1, i(this, H, Date.now()), o && i(this, D, e != null && e.element && Q(e.element) || window);
  }
  connect() {
    o && t(this, D).addEventListener(
      "wheel",
      t(this, N),
      {
        passive: !1
      }
    );
  }
  disconnect() {
    o && (t(this, D).removeEventListener(
      "wheel",
      t(this, N)
    ), clearTimeout(t(this, x)));
  }
}
D = new WeakMap(), x = new WeakMap(), H = new WeakMap(), N = new WeakMap();
var L, u, l, z, E;
const y = class y extends B {
  constructor(e) {
    super();
    s(this, u);
    s(this, l);
    s(this, z);
    s(this, E);
    this.inertion = 1, i(this, u, null), i(this, l, 0), i(this, z, (a) => {
      if (a.composedPath().find(
        (M) => M instanceof HTMLElement && M.hasAttribute("drag-dead-zone")
      ))
        return;
      this.swipe || k.unsubscribe(t(this, E));
      let r = a, F = !1;
      i(this, l, 0), document.documentElement.classList.add("grabbing");
      let R = 0, W = 0;
      $(
        (M) => {
          t(y, L) && t(y, L) !== t(this, u) || (R = r.x - M.x, W = r.y - M.y, this.axis === "x" ? i(this, l, R) : i(this, l, W), r = M, F = this.axis === "x" && Math.abs(R) > Math.abs(W) || this.axis === "y" && Math.abs(W) > Math.abs(R), F && (document.documentElement.classList.add("dragging"), i(y, L, t(this, u)), this.changeEvent.notify("drag", t(this, l))));
        },
        () => {
          i(y, L, null), F && !this.swipe && this.inertion ? (i(this, l, t(this, l) * this.inertion), k.subscribe(t(this, E), {
            order: _.CONTROLS - 1
          })) : this.swipe && this.changeEvent.notify("drag-end", t(this, l)), document.documentElement.classList.remove("grabbing"), document.documentElement.classList.remove("dragging");
        }
      );
    }), i(this, E, () => {
      Math.floor(Math.abs(t(this, l))) || k.unsubscribe(t(this, E)), i(this, l, t(this, l) * 0.95), i(this, l, p(t(this, l), 3)), this.changeEvent.notify("drag", t(this, l));
    }), this.axis = (e == null ? void 0 : e.axis) || "y", this.swipe = (e == null ? void 0 : e.swipe) || !1, o && i(this, u, e != null && e.element && Q(e.element) || document.documentElement);
  }
  connect() {
    o && t(this, u).addEventListener("pointerdown", t(this, z));
  }
  disconnect() {
    o && (t(this, u).removeEventListener(
      "pointerdown",
      t(this, z)
    ), k.unsubscribe(t(this, E)));
  }
};
L = new WeakMap(), u = new WeakMap(), l = new WeakMap(), z = new WeakMap(), E = new WeakMap(), s(y, L, null);
let j = y;
export {
  fe as AutoplayControls,
  B as Controls,
  j as DragControls,
  me as KeyboardControls,
  ue as WheelControls
};

==> aptechka-0.44.1.tgz: package/lib/controls/index.js <==
var V = (h) => {
  throw TypeError(h);
};
var S = (h, n, e) => n.has(h) || V("Cannot " + e);
var t = (h, n, e) => (S(h, n, "read from private field"), e ? e.call(h) : n.get(h)), s = (h, n, e) => n.has(h) ? V("Cannot add the same private member more than once") : n instanceof WeakSet ? n.add(h) : n.set(h, e), i = (h, n, e, a) => (S(h, n, "write to private field"), a ? a.call(h, e) : n.set(h, e), e), T = (h, n, e) => (S(h, n, "access private method"), e);
import { Notifier as G } from "../notifier/index.js";
import { i as o } from "../index-euf5anj6.js";
import { g as Q } from "../dom-CVWzyXPH.js";
import { ticker as k } from "../ticker/index.js";
import "../Store-D2xCXENW.js";
import { b as J } from "../easings-Bni3YAAW.js";
import { T as Z } from "../Tweened-BNCj14Jz.js";
import { s as $ } from "../gestures-D2Fdra_G.js";
import { p } from "../polyfills-CxfUK5OU.js";
import { TICK_ORDER as _ } from "../order/index.js";
var O;
class B {
  constructor() {
    s(this, O, new G());
  }
  get changeEvent() {
    return t(this, O);
  }
}
O = new WeakMap();
var g, d, m, P;
class me extends B {
  constructor(e) {
    super();
    s(this, g, null);
    s(this, d, null);
    s(this, m, "offsetHeight");
    s(this, P, (e) => {
      const a = e.shiftKey ? -1 : 1;
      let r;
      e.code === "Space" ? r = a * t(this, d)[t(this, m)] * 0.4 : e.code === "ArrowLeft" ? r = -1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowRight" ? r = 1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowUp" ? r = -1 * t(this, d)[t(this, m)] * 0.2 : e.code === "ArrowDown" ? r = 1 * t(this, d)[t(this, m)] * 0.2 : e.code === "PageUp" ? r = -1 * t(this, d)[t(this, m)] : e.code === "PageDown" ? r = 1 * t(this, d)[t(this, m)] : e.code === "Home" ? r = 0 : e.code === "End" && (r = t(this, m) === "offsetWidth" ? t(this, d).scrollWidth : t(this, d).scrollHeight), r && (e.stopPropagation(), this.changeEvent.notify("keyboard", r));
    });
    o && (i(this, g, e != null && e.element && Q(e.element) || window), i(this, d, t(this, g) instanceof HTMLElement ? t(this, g) : document.documentElement), this.dimension = e == null ? void 0 : e.dimension);
  }
  set dimension(e) {
    i(this, m, e === "width" ? "offsetWidth" : "offsetHeight");
  }
  connect() {
    o && t(this, g).addEventListener(
      "keydown",
      t(this, P)
    );
  }
  disconnect() {
    o && t(this, g).removeEventListener(
      "keydown",
      t(this, P)
    );
  }
}
g = new WeakMap(), d = new WeakMap(), m = new WeakMap(), P = new WeakMap();
var w, v, X, Y, c, C, f, b, K, U, A, q, I;
class fe extends B {
  constructor(e) {
    super();
    s(this, b);
    s(this, w);
    s(this, v);
    s(this, X);
    s(this, Y);
    s(this, c);
    s(this, C);
    s(this, f);
    s(this, A);
    s(this, q);
    s(this, I);
    this.direction = 1, i(this, c, new Z(0, { easing: J })), i(this, f, !1), i(this, A, (a) => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        a.timeBetweenFrames * t(this, w) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, q, () => {
      t(this, c).current !== 1 && this.changeEvent.notify(
        "autoplay",
        Math.sign(t(this, w)) * this.direction * (1 - t(this, c).current)
      );
    }), i(this, I, () => {
      t(this, v) && (document.hidden ? t(this, c).set(1, { equalize: !0 }) : t(this, c).set(0, { equalize: !0 }));
    }), i(this, w, (e == null ? void 0 : e.speed) || 1), i(this, v, (e == null ? void 0 : e.interval) || !1), i(this, X, e);
  }
  set interval(e) {
    i(this, v, e), t(this, f) && T(this, b, K).call(this);
  }
  set speed(e) {
    i(this, w, e), t(this, f) && T(this, b, K).call(this);
  }
  connect() {
    t(this, f) || (i(this, f, !0), T(this, b, K).call(this));
  }
  disconnect() {
    t(this, f) && (i(this, f, !1), T(this, b, U).call(this));
  }
  pauseAndContinue(e, a) {
    t(this, f) && e && (clearTimeout(t(this, C)), t(this, c).set(1, {
      duration: Math.min(e, 1e3),
      equalize: a
    }), i(this, C, setTimeout(() => {
      t(this, c).set(0, {
        duration: Math.min(e, 5e3),
        equalize: a
      });
    }, e)));
  }
}
w = new WeakMap(), v = new WeakMap(), X = new WeakMap(), Y = new WeakMap(), c = new WeakMap(), C = new WeakMap(), f = new WeakMap(), b = new WeakSet(), K = function() {
  T(this, b, U).call(this), t(this, v) ? i(this, Y, setInterval(
    t(this, q),
    Math.abs(t(this, w))
  )) : k.subscribe(t(this, A), t(this, X)), document.addEventListener(
    "visibilitychange",
    t(this, I)
  );
}, U = function() {
  clearInterval(t(this, Y)), k.unsubscribe(t(this, A)), clearTimeout(t(this, C)), t(this, c).close(), document.removeEventListener(
    "visibilitychange",
    t(this, I)
  );
}, A = new WeakMap(), q = new WeakMap(), I = new WeakMap();
var D, x, H, N;
class ue extends B {
  constructor(e) {
    super();
    s(this, D, null);
    s(this, x);
    s(this, H);
    s(this, N, (e) => {
      let a = 0;
      if (!(this.axis === "x" && Math.abs(e.deltaY) > Math.abs(e.deltaX) * 1 || this.axis === "y" && Math.abs(e.deltaX) > Math.abs(e.deltaY) * 1))
        if (e.preventDefault(), a = (this.axis === "max" ? Math.abs(e.deltaX) > Math.abs(e.deltaY) ? e.deltaX : e.deltaY : this.axis === "x" ? e.deltaX : e.deltaY) * this.speed, e.stopPropagation(), this.debounce) {
          const r = Date.now();
          if (r - t(this, H) > 40 && (a = 100 * Math.sign(a)), i(this, H, r), Math.abs(a) < 100 || t(this, x))
            return;
          this.changeEvent.notify("wheel", a), i(this, x, setTimeout(() => {
            i(this, x, void 0);
          }, 80));
        } else
          this.changeEvent.notify("wheel", a);
    });
    this.axis = (e == null ? void 0 : e.axis) || "y", this.speed = (e == null ? void 0 : e.speed) || 1, this.debounce = (e == null ? void 0 : e.debounce) || !1, i(this, H, Date.now()), o && i(this, D, e != null && e.element && Q(e.element) || window);
  }
  connect() {
    o && t(this, D).addEventListener(
      "wheel",
      t(this, N),
      {
        passive: !1
      }
    );
  }
  disconnect() {
    o && (t(this, D).removeEventListener(
      "wheel",
      t(this, N)
    ), clearTimeout(t(this, x)));
  }
}
D = new WeakMap(), x = new WeakMap(), H = new WeakMap(), N = new WeakMap();
var L, u, l, z, E;
const y = class y extends B {
  constructor(e) {
    super();
    s(this, u);
    s(this, l);
    s(this, z);
    s(this, E);
    this.inertion = 1, i(this, u, null), i(this, l, 0), i(this, z, (a) => {
      if (a.composedPath().find(
        (M) => M instanceof HTMLElement && M.hasAttribute("drag-dead-zone")
      ))
        return;
      this.swipe || k.unsubscribe(t(this, E));
      let r = a, F = !1;
      i(this, l, 0), document.documentElement.classList.add("grabbing");
      let R = 0, W = 0;
      $(
        (M) => {
          t(y, L) && t(y, L) !== t(this, u) || (R = r.x - M.x, W = r.y - M.y, this.axis === "x" ? i(this, l, R) : i(this, l, W), r = M, F = this.axis === "x" && Math.abs(R) > Math.abs(W) || this.axis === "y" && Math.abs(W) > Math.abs(R), F && (document.documentElement.classList.add("dragging"), i(y, L, t(this, u)), this.changeEvent.notify("drag", t(this, l))));
        },
        () => {
          i(y, L, null), F && !this.swipe && this.inertion ? (i(this, l, t(this, l) * this.inertion), k.subscribe(t(this, E), {
            order: _.CONTROLS - 1
          })) : this.swipe && this.changeEvent.notify("drag-end", t(this, l)), document.documentElement.classList.remove("grabbing"), document.documentElement.classList.remove("dragging");
        }
      );
    }), i(this, E, () => {
      Math.floor(Math.abs(t(this, l))) || k.unsubscribe(t(this, E)), i(this, l, t(this, l) * 0.95), i(this, l, p(t(this, l), 3)), this.changeEvent.notify("drag", t(this, l));
    }), this.axis = (e == null ? void 0 : e.axis) || "y", this.swipe = (e == null ? void 0 : e.swipe) || !1, o && i(this, u, e != null && e.element && Q(e.element) || document.documentElement);
  }
  connect() {
    o && t(this, u).addEventListener("pointerdown", t(this, z));
  }
  disconnect() {
    o && (t(this, u).removeEventListener(
      "pointerdown",
      t(this, z)
    ), k.unsubscribe(t(this, E)));
  }
};
L = new WeakMap(), u = new WeakMap(), l = new WeakMap(), z = new WeakMap(), E = new WeakMap(), s(y, L, null);
let j = y;
export {
  fe as AutoplayControls,
  B as Controls,
  j as DragControls,
  me as KeyboardControls,
  ue as WheelControls
};
